@@ -89,6 +89,7 @@ GType gda_xa_transaction_get_type(void);
 
 //Declarations of the *_error_quark() functions:
 
+GQuark gda_config_error_quark(void);
 GQuark gda_connection_error_quark(void);
 GQuark gda_data_model_error_quark(void);
 GQuark gda_data_model_iter_error_quark(void);
@@ -142,17 +143,18 @@ namespace Gnome { namespace Gda {
 void wrap_init()
 {
   // Register Error domains:
-  Glib::Error::register_domain(gda_connection_error_quark(), &Gnome::Gda::ConnectionError::throw_func);
-  Glib::Error::register_domain(gda_data_model_error_quark(), &Gnome::Gda::DataModelError::throw_func);
-  Glib::Error::register_domain(gda_data_model_iter_error_quark(), &Gnome::Gda::DataModelIterError::throw_func);
-  Glib::Error::register_domain(gda_holder_error_quark(), &Gnome::Gda::HolderError::throw_func);
-  Glib::Error::register_domain(gda_meta_store_error_quark(), &Gnome::Gda::MetaStoreError::throw_func);
-  Glib::Error::register_domain(gda_meta_struct_error_quark(), &Gnome::Gda::MetaStructError::throw_func);
-  Glib::Error::register_domain(gda_server_provider_error_quark(), &Gnome::Gda::ServerProviderError::throw_func);
-  Glib::Error::register_domain(gda_sql_builder_error_quark(), &Gnome::Gda::SqlBuilderError::throw_func);
-  Glib::Error::register_domain(gda_sql_error_quark(), &Gnome::Gda::SqlError::throw_func);
-  Glib::Error::register_domain(gda_sql_parser_error_quark(), &Gnome::Gda::SqlParserError::throw_func);
-  Glib::Error::register_domain(gda_statement_error_quark(), &Gnome::Gda::StatementError::throw_func);
+  Glib::Error::register_domain(gda_config_error_quark(), &::Gnome::Gda::ConfigError::throw_func);
+  Glib::Error::register_domain(gda_connection_error_quark(), &::Gnome::Gda::ConnectionError::throw_func);
+  Glib::Error::register_domain(gda_data_model_error_quark(), &::Gnome::Gda::DataModelError::throw_func);
+  Glib::Error::register_domain(gda_data_model_iter_error_quark(), &::Gnome::Gda::DataModelIterError::throw_func);
+  Glib::Error::register_domain(gda_holder_error_quark(), &::Gnome::Gda::HolderError::throw_func);
+  Glib::Error::register_domain(gda_meta_store_error_quark(), &::Gnome::Gda::MetaStoreError::throw_func);
+  Glib::Error::register_domain(gda_meta_struct_error_quark(), &::Gnome::Gda::MetaStructError::throw_func);
+  Glib::Error::register_domain(gda_server_provider_error_quark(), &::Gnome::Gda::ServerProviderError::throw_func);
+  Glib::Error::register_domain(gda_sql_builder_error_quark(), &::Gnome::Gda::SqlBuilderError::throw_func);
+  Glib::Error::register_domain(gda_sql_error_quark(), &::Gnome::Gda::SqlError::throw_func);
+  Glib::Error::register_domain(gda_sql_parser_error_quark(), &::Gnome::Gda::SqlParserError::throw_func);
+  Glib::Error::register_domain(gda_statement_error_quark(), &::Gnome::Gda::StatementError::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(gda_batch_get_type(), &Gnome::Gda::Batch_Class::wrap_new);
